==> 3.0.23.tar.gz: net/sample/src/main/java/com/drake/net/sample/ui/fragment/PullRefreshFragment.kt <==
/*
 * Copyright (C) 2018 Drake, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.drake.net.sample.ui.fragment

import com.drake.brv.utils.linear
import com.drake.brv.utils.setup
import com.drake.engine.base.EngineFragment
import com.drake.net.Get
import com.drake.net.sample.R
import com.drake.net.sample.databinding.FragmentPullRefreshBinding
import com.drake.net.sample.model.UserModel
import com.drake.net.utils.scope


class PullRefreshFragment :
    EngineFragment<FragmentPullRefreshBinding>(R.layout.fragment_pull_refresh) {

    override fun initView() {
        binding.rv.linear().setup {
            addType<UserModel>(R.layout.item_list)
        }

        binding.page.onRefresh {
            scope {
                val data = Get<List<UserModel>>("list") {
                    param("page", index)
                }.await()
                addData(data) {
                    index < 100 // 最多加载100个
                }
            }
        }.autoRefresh()
    }

    override fun initData() {
    }

}

==> 3.3.0.tar.gz: net/sample/src/main/java/com/drake/net/sample/ui/fragment/PullRefreshFragment.kt <==
/*
 * Copyright (C) 2018 Drake, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.drake.net.sample.ui.fragment

import com.drake.brv.utils.linear
import com.drake.brv.utils.setup
import com.drake.engine.base.EngineFragment
import com.drake.net.Get
import com.drake.net.sample.R
import com.drake.net.sample.databinding.FragmentPullRefreshBinding
import com.drake.net.sample.model.GameInfoModel
import com.drake.net.utils.scope


class PullRefreshFragment :
    EngineFragment<FragmentPullRefreshBinding>(R.layout.fragment_pull_refresh) {

    override fun initView() {
        binding.rv.linear().setup {
            addType<GameInfoModel>(R.layout.item_list)
        }

        binding.page.onRefresh {
            scope {
                val data = Get<List<GameInfoModel>>("list") {
                    param("page", index)
                }.await()
                addData(data) {
                    index < 100 // 最多加载100个
                }
            }
        }.autoRefresh()
    }

    override fun initData() {
    }

}
